@@ -161,6 +161,9 @@ class Request:
         elif isinstance(settings.REQUEST_DELAY, list):
             time.sleep(random.choice([i for i in range(settings.REQUEST_DELAY[0], settings.REQUEST_DELAY[1] + 1)]))
 
+        # cookie_jar 更新传入的 cookie
+        self.cookie_jar.update(self.cookies)
+
         # 获取响应
         response = self.downloader(
             **self._requests_params,
@@ -203,6 +206,8 @@ class Request:
             self.headers = {}
         if self.cookies is None:
             self.cookies = {}
+        elif isinstance(self.cookies, tuple):
+            self.cookies = dict(self.cookies)
         if self.timeout is None:
             self.timeout = settings.REQUEST_TIMEOUT or 60
         self._requests_params.setdefault('verify', False)
